@@ -26,11 +26,10 @@ THDNUM_DEFAULT = int(THDNUM_MAXIMUM / 2)
 
 
 class scanner:
-    '''
-    scan objects
+    '''scan objects
     '''
 
-    class object:
+    class object:  # pylint: disable=too-many-public-methods
 
         def __init__(self, path: str):
             assert isinstance(path, str)
@@ -60,15 +59,13 @@ class scanner:
 
         @property
         def uid(self) -> int:
-            '''
-            user id of owner
+            '''user id of owner
             '''
             return self.stat.st_uid
 
         @property
         def gid(self) -> int:
-            '''
-            group id of owner
+            '''group id of owner
             '''
             return self.stat.st_gid
 
@@ -82,15 +79,13 @@ class scanner:
 
         @property
         def atime(self) -> float:
-            '''
-            time of most recent access
+            '''time of most recent access
             '''
             return self.stat.st_atime
 
         @property
         def mtime(self) -> float:
-            '''
-            time of most recent content modification
+            '''time of most recent content modification
             '''
             return self.stat.st_mtime
 
@@ -125,9 +120,9 @@ class scanner:
                     data = fhandler.read(size)
                     if not data:
                         break
-                    for hash in args:
-                        hash.update(data)
-            return (hash.hexdigest() for hash in args)
+                    for obj in args:
+                        obj.update(data)
+            return (obj.hexdigest() for obj in args)
 
         @property
         def md5(self) -> str:
@@ -145,7 +140,7 @@ class scanner:
             return code
 
     def __init__(self):
-        self.__objdict: Dict[str, scanner.object] = dict()
+        self.__objdict: Dict[str, scanner.object] = {}
         self.__objects: Set[scanner.object] = set()
         self.__objsyms: Set[scanner.object] = set()
         self.__objregs: Set[scanner.object] = set()
@@ -182,12 +177,15 @@ class scanner:
                 self.__objregs.add(obj)
 
     @classmethod
-    def load(cls,
+    def load(cls,  # pylint: disable=R0913,R0914,R0915
              paths: Sequence[str],
-             exclude: Sequence[str] = [],
+             exclude: Optional[Sequence[str]] = None,
              linkdir: bool = True,
              threads: int = THDNUM_DEFAULT,
              handler: Optional[Callable[[object], bool]] = None):
+        if exclude is None:
+            exclude = []
+
         assert isinstance(paths, Sequence)
         assert isinstance(exclude, Sequence)
         assert isinstance(linkdir, bool)
@@ -201,7 +199,7 @@ class scanner:
             return os.path.relpath(path)
 
         # filter files and directorys
-        def filter() -> Set[str]:
+        def path_filter() -> Set[str]:
             filter_paths: Set[str] = set()
 
             for path in exclude:
@@ -209,22 +207,22 @@ class scanner:
 
             return filter_paths
 
-        class task_stat:
+        class task_stat:  # pylint: disable=too-few-public-methods
 
             def __init__(self):
                 self.exit = False
                 self.handler = handler
                 self.scanner = scanner()
-                self.filter: Set[str] = filter()
-                self.q_path: Queue[str] = Queue()
-                self.q_task: Queue[scanner.object] = Queue(maxsize=thds * 2)
+                self.filter: Set[str] = path_filter()
+                self.q_path: "Queue[str]" = Queue()
+                self.q_task: "Queue[scanner.object]" = Queue(maxsize=thds * 2)
 
         scan_stat = task_stat()
 
         def task_scan_path():
             scanned_dirs = set()
             name = current_thread().name
-            cmds.logger.debug(f"task thread[{name}] start")
+            cmds.logger.debug("task thread[%s] start", name)
             while not scan_stat.exit or not scan_stat.q_path.empty():
                 try:
                     path = scan_stat.q_path.get(timeout=0.01)
@@ -235,7 +233,7 @@ class scanner:
                 assert isinstance(path, str)
 
                 if path in scan_stat.filter or not os.path.exists(path):
-                    cmds.logger.debug(f"scan filter {path}")
+                    cmds.logger.debug("scan filter %s", path)
                     scan_stat.q_path.task_done()
                     continue
 
@@ -247,31 +245,31 @@ class scanner:
                             spath = os.path.join(path, sub)
                             scan_stat.q_path.put(spath)
 
-                result = True
-                object = scanner.object(path)
+                ret = True
+                obj = scanner.object(path)
 
                 if isinstance(scan_stat.handler, Callable):
-                    result = scan_stat.handler(object)
-                    assert isinstance(result, bool)
+                    ret = scan_stat.handler(obj)
+                    assert isinstance(ret, bool)
 
-                if result is True:
-                    scan_stat.q_task.put(object)
+                if ret is True:
+                    scan_stat.q_task.put(obj)
                 scan_stat.q_path.task_done()
-            cmds.logger.debug(f"task thread[{name}] exit")
+            cmds.logger.debug("task thread[%s] exit", name)
 
         def task_scan():
             name = current_thread().name
-            cmds.logger.debug(f"task thread[{name}] start")
+            cmds.logger.debug("task thread[%s] start", name)
             while not scan_stat.exit or not scan_stat.q_task.empty():
                 try:
                     obj = scan_stat.q_task.get(timeout=0.01)
                 except Empty:
                     continue
 
-                cmds.logger.debug(f"scan {obj.path}")
+                cmds.logger.debug("scan %s", obj.path)
                 scan_stat.scanner.add(obj=obj)
                 scan_stat.q_task.task_done()
-            cmds.logger.debug(f"task thread[{name}] exit")
+            cmds.logger.debug("task thread[%s] exit", name)
 
         task_threads: List[Thread] = []
         task_threads.append(Thread(target=task_scan, name="xarg-scan"))
